#include <config.h>

#include "Inset.h"

#include <boost/any.hpp>
#include <boost/assert.hpp>
#include <boost/function.hpp>
#include <boost/regex.hpp>
#include <boost/scoped_ptr.hpp>
#include <boost/signals/connection.hpp>
#include <boost/signal.hpp>
#include <boost/signals/trackable.hpp>
#include <boost/tuple/tuple.hpp>
#include <boost/utility.hpp>

#include <cmath>
#include <fstream>
#include <iosfwd>
#include <iostream>
#include <map>
#include <memory>
#include <sstream>
#include <string>
#include <vector>
